--[[----------------------------------------------------------------------------
Copyright (c) 2011, Danny Fritz <dannyfritz@gmail.com>
http://creativecommons.org/licenses/by/3.0/
Licensed under the Creative Commons Attribution 3.0 Unported License.
--]]----------------------------------------------------------------------------

local LoveSplash = Gamestate:addState('LoveSplash')

local Tween = require 'lib.tween.tween'
local Object = require 'splash.Object'

local NEXTSTATE = 'Splash'

local splash
local orange
local stars
local number_stars = 20

--------------------------------------------------------------------------------
function LoveSplash:enteredState()
	love.graphics.setBackgroundColor(131, 192, 240)

	stars = {}
	local star_image = love.graphics.newImage('splash/star.png')
	for i=0, number_stars do
		local p = love.graphics.newParticleSystem( star_image, 128 )
		p:setDirection(-math.pi/2)
		p:setSpread(math.pi)
		ParticleSetColors(p, 31,120,183,100, 31,120,183,0)
		p:setEmissionRate(2)
		p:setSpeed(100, 150)
		p:setGravity(0, 0)
		ParticleSetSizes(p, 0.2, 0.1)
		p:setSizeVariation(1)
		p:setLifetime(-1)
		p:setParticleLife(2)
		p:setRadialAcceleration(-120)
		p:setTangentialAcceleration(0)
		p:setSpin(-1,1, 1)
		p:start()
		table.insert(stars, p)
	end

	orange={alpha=0}

	local splash_image = love.graphics.newImage('splash/love-splash-no-stars.png')
	splash = Object:new(splash_image, {alpha=0})
	Tween(1, splash, {alpha=255}, 'linear',
	Tween, 1, splash, {}, 'linear',
	Tween, 0.5, orange, {alpha=255}, 'linear',
	gamestate.gotoState, gamestate, NEXTSTATE)
end

--------------------------------------------------------------------------------
function LoveSplash:exitedState()
end

--------------------------------------------------------------------------------
function LoveSplash:update(dt)
	Tween.update(dt)
	for _,p in pairs(stars) do
		p:update(dt)
	end
end

--------------------------------------------------------------------------------
function LoveSplash:draw()
	love.graphics.setColor(255, 255, 255, 255)
	splash:draw()
	for i=1, #stars do
		love.graphics.draw(stars[i], 800*i/#stars, 640)
	end
	love.graphics.setColor(254, 153, 0, orange.alpha)
	love.graphics.rectangle('fill', 0,0, 800, 600)
end

--------------------------------------------------------------------------------
function LoveSplash:keypressed(key, unicode)
	if key == ' ' or key == 'return' or key == 'kpenter' or key == 'escape' then
		gamestate:gotoState(NEXTSTATE)
	end
end

--------------------------------------------------------------------------------
function LoveSplash:mousepressed(x, y, button)
	gamestate:gotoState(NEXTSTATE)
end

--------------------------------------------------------------------------------
function LoveSplash:joystickpressed(joystick, button)
	gamestate:gotoState(NEXTSTATE)
end

--------------------------------------------------------------------------------
function ParticleSetColors(particle, ...)
	if particle.setColors then
		particle:setColors(...)
	else
		particle:setColor(...)
	end
end

function ParticleSetSizes(particle, ...)
	if particle.setSizes then
		particle:setSizes(...)
	else
		particle:setSize(...)
	end
end
